/******************
	DATEI
	NEWGROW.H : Header-Datei zu NEWGROW.C, 
	            der Schnittstelle zu S-Plus;
******************/

#ifndef __NEWGROW__
#define __NEWGROW__

/******************
	TYPDEFINITIONEN 
	Y_STRUCT: Wird vor allem in der Prozedur "log_rank" 
	          zur Berechnung des Testwertes benutzt.
******************/

typedef struct 
{
	DOUBLE   time;    /* die Ueberlebenszeit      */
	BOOLEAN  zensor;  /* der Zensierungsindikator */
	BOOLEAN  group;   /* die Gruppenzugehoerigkeit,
	                     wird nur in "log_rank" benutzt */
} Y_STRUCT;

/******************
	GLOBALE VARIABLEN
	minsize_global  : Minimale Fall-Anzahl, bei der ein 
	                  Knoten noch gesplittet werden darf;
	mincut_global   : Minimale Fall-Anzahl, die jeder der
	                  2 Nachfolgerknoten eines Splittes
	                  haben muss;
	left_global     : linke Grenze aus der Miller-
	                  Siegmund-Foreml zur Berechnung
	                  der Signifikanz des maximal se-
	                  lektierten Split-Punktes
	right_global    : rechte Grenze
	anz_xvars_global: Anzahl der Covariablen;
	nobs_global     : Anzahl der Beobachtungseinheiten
	                  insgesamt;
	ask_flag_global : Flag, ob der Benutzer die Split-
	                  Variable bestimmt;

	xvars_global    : Zeiger auf den array mit den 
	                  Covariablendaten, Anzahl seiner 
	                  Elemente ist
	                  "nobs_global * anz_xvars_global";
	xlevels_global  : Zeiger auf array der Groesse
	                  "anz_xvars_global"; Inhalt jedes 
	                  dessen Elemente ist bei nominaler
	                  Covariable die Anzahl seiner 
	                  moeglichen Merkmalsauspraegungen;
	xstring_global  : Zeiger auf array mit den Namen der
	                  faktoriellen X-Variablen
	xlstring_global : Zeiger auf array mit den Namen der
	                  Faktoren von faktoriellen X-Variablen
	y_global        : Zeiger auf array der Zielvariablen;
	
******************/

GLOBAL UWORD mincut_global;
GLOBAL UWORD minsize_global;
GLOBAL DOUBLE left_global;
GLOBAL DOUBLE right_global;
GLOBAL UWORD anz_xvars_global;
GLOBAL UWORD nobs_global;
GLOBAL UWORD ask_flag_global;
GLOBAL UWORD log_flag_global;

GLOBAL UWORD    * xlevels_global;
GLOBAL DOUBLE   * xvars_global;
GLOBAL BYTE    ** xstring_global;
GLOBAL BYTE    ** xlstring_global;
GLOBAL BYTE    ** datei_name_global;
GLOBAL Y_STRUCT * y_global;
GLOBAL UWORD    * fact_fl_global;

/******************
	GLOBALE FUNKTIONEN 
	newgrow : dies ist die Schnittstelle zu S-Plus;
******************/

VOID newgrow(
	/* hier die ersten Eingabevariblen                */

	DOUBLE * X,      /* Covariablenmatrix der Groesse
	                    "nobs" * "ncloX"              */
	DOUBLE * Y,      /* Zielvariablen-array           */        
	DOUBLE * w,      /* array mit Gewichten
	                    fuer Beobachtungen, wird noch
	                    nicht benutzt. In spaeterer 
	                    Version vorgesehen            */
	WORD * XYlevels, /* array der Groesse "ncolX" + 1
	                    X oder Y nominal ? Anz. der
	                    Merkmalsauspraegungen         */
	BYTE **Xstring,  /* array mit den Namen der 
	                    X-Variablen                   */
	BYTE **Xlstring,  /* array mit den Namen der Levels
	                    X-Variablen                   */
	WORD * Yzensor,  /* Zensierungs-array             */
	WORD * nobs,     /* Anz. der Beobachtungseinheiten*/
	WORD * ncolX,    /* Anz. der X-Variablen          */
	WORD * Ask_flag, /* Flag, ob ein Split durch den
	                    Benutzer beeinflusst werden soll */
	WORD * Log_flag, /* Flag, ob diese Beeinflussung in
	                    einer Datei gespeichert werden
	                    soll                          */
	BYTE **Datei_name,  /* Name dieser Datei          */

	/* hier die ersten Variablen mit Rueckgabewert    */

	WORD * node,     /* Knotennummern-array           */
	WORD * var,      /* array mit den Nummern
	                    der Variablen die den Knoten
	                    verzweigen lassen             */
	BYTE ** cutleft, /* array mit dem
	                    Intervall von "var",
	                    das nach links geht           */
	BYTE ** cutright,/* array mit dem
	                    Intervall von "var",
	                    das nach rechts geht          */
	WORD * n,        /* array mit den
	                    Anz. der Faelle der Knoten    */
	DOUBLE * dev,     /* Pseudo-Deviance, wird durch 
	                     Summierung der log-rank Werte
	                     erhalten                     */
	DOUBLE * log_rank,/* "log_rank"-values der Knoten */
	DOUBLE * log_alph,/* "log_rank"-Siginifikanz 
	                     von "log_rank"               */

	/* hier nochmal einige Eingabevariablen           */

	WORD * minsize,  /* minimale Anzahl mit der ein 
	                    Knoten noch gespalten 
	                    werden darf                   */
	WORD * mincut,   /* minimale Anzahl die jeder der 2
	                    Nachfolgerknoten noch 
	                    haben muss                    */
	DOUBLE * left_t, /* linke Grenze aus der Miller-
	                    Siegmund-Foreml zur Berechnung
	                    der Signifikanz des maximal se-
	                    lektierten Split-Punktes      */
	DOUBLE * right_t,/* rechte Grenze                 */


	VOID **Spchisq_p,/* Wahrscheinichkeits-
	                    chi-Quadrat-Funktion von S_Plus*/

	VOID **Sqchisq_p,/* Quantil-
	                    chi-Quadrat-Funktion von S_Plus*/

	VOID **Sreadline_p,/* Eingabe-funktion */
	
	WORD * fact_flag,/* Array mit boolschen Werten, die
	                    anzeigen, ob die X-Variablen
	                    geordnete Faktoren oder 
	                    stetige Variablen sind        */
	/* hier nochmal einige mit Rueckgabewert           */

	WORD * nnode,    /* Anzahl der Knoten insgesamt   */
	WORD * where     /* array mit Indizes, zeigt fuer
	                    jede Beobachtungseinheit auf
	                    seinen Endknoten              */
);

#endif /* __NEWGROW__ */
