.BG
.FN survtree
.TL
Fit a Tree-Based Model for Survival Time Data
.DN
Works similiar to function `tree', but only for Survival Time Data.
.CS
survtree(formula=formula(data), data=sys.parent(), zensor, 
         fact.flag, ask.flag=0, left.t=0.1, right.t=0.9, file, 
         weights, subset, na.action, control=tree.control(nobs, ...), 
         method="recursive.partition", model=NULL, x=F, y=T, z=T, ...)
.AG formula
a formula expression as for other regression models,
of the form `survival-time-variable ~ predictors'.
.AG data
an optional data frame in which to interpret the variables named in
the `formula', `subset', and `weights' arguments.
.AG zensor
vector of status values.  The values have to be `0' or `1', in which case
`0' means censored and `1' means uncensored (dead).
.AG fact.flag
vector of logical, the length of `fact.flag' is equal to 
the number of predictors. It is neccessary to distinguish
between condinuous variables and others (e.g. variables of type
ordered or discrete with few different values)
.PP
`fact.flag[i] == FALSE' means : i-th predictor is not a continuous variable  
.PP
`fact.flag[i] == TRUE'  means : i-th predictor is a continuous variable  
.AG ask.flag
logical value, if `TRUE' then the splitting process runs interactively.
.AG left.t
numeric value between 0 and 1, meaning see section DETAILS (*) below
.AG right.t
numeric value between `left.t' and 1, meaning see section DETAILS (*) below
.AG file
character string, giving the name of an (new created) ASCII-File. In
the case of choosing `ask.flag == TRUE' the interactive splitting
process is logged to this file.
.AG weights
.PP
(+++ SORRY, weights are not yet implemented !!! +++)
.PP
optional prior observation weights; can have zeros,
although the `subset' argument is preferred for deleting observations.
.AG subset
an expression  to be used to subset the rows of the  model frame
prior to fitting.
.AG na.action
a missing data filter function, which gets applied to the model frame.
.AG method
if method is `"model.frame"', the function returns the model frame
used to build the tree.
.AG control
a list of iteration and algorithmic constants.
See `tree.control' for their names and default values.
These can also be set as arguments to `survtree' itself.
.PP
REMARK: argument `mindev' is ignored in the current version of `survtree' !!!
.AG model
if this argument is itself a model frame, then the `formula' and
`data' arguments are ignored, and `model' is used to define the model.
.AG x
if `TRUE', the `model.matrix' is returned.
.AG y
if `TRUE', the response variable is returned.
.AG ...
additional arguments for the fitting routines such as `tree.control'.
.RT
an object of class `survtree' is returned.
.DT
The model is fit using \f2binary recursive partitioning\f1 whereby the
data are successively \f2split\f1 along coordinate axes of the
predictor variables so that at any \f2node\f1, the split which
maximally distinguishes the survival-time-variable in the left and the
right branches is selected.  Splitting continues until nodes are pure
or data are too sparse; terminal nodes are called \f2leaves\f1, while
the initial node is called the \f2root\f1.
.PP
(*) The split-process is based on the log-rank-test. For continuous
variables an approximated distribution function for maximally selected
rank statistics (suggested by Lausen and Schumacher (1992)) is
used. The meaning of the arguments `left.t' and `right.t' can be found in
the article of Miller and Siegmund (1982, page 1013, formula 8: t1 =
`left.t', t2 = `right.t').
.PP
This can be examined by `print' and `plot'.  Contents can be extracted
using `predict', and `formula'.  Can be modified using `update'.
Other generic functions that have methods for `tree' objects are
`text', `identify', `browser', and `['.
.PP
(+++ SORRY, some important functions (`summary.survtree',
`tile.survtree', `burl.survtree') are not yet implemented !!! +++)
.SH REFERENCES
Breiman L., Friedman J.H., Olshen R.A., and Stone, C.J., (1984).
.ul
Classification and Regression Trees.
Wadsworth International Group, Belmont CA.
.PP
Lausen B. and Schumacher M., (1992). 
Maximally selected rank statistics.
.ul
Biometrics, 
48:73-85
.PP
Miller R. and Siegmund D. (1982).
Maximally selected chi-squared statistics 
.ul
Biometrics,
38:1011-1016
.SA
`predict.survtree', `edit.survtree', `prune.survtree', `graph.survtree'.
.EX
# fit survival tree to liver metastases data
LM.form <- formula(t ~ pt + tnm + anz + lap + lrg + sex + sm + dm + age)
LM.fac <- c(rep(F,7),rep(T,2))
LM.tree <- survtree(LM.form, LM, LM$z, LM.fac)

# fit to same data, but do it interactively and log 
# this interactive process to the file 'LM.tree.logg'
LM.tree <- survtree(LM.form, LM, LM$z, LM.fac, ask.flag = 3,
                   file = "LM.tree.logg")
.KW survtree
.WR
